"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IdentityServerController = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_2 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const repositories_1 = require("../../../repositories");
const services_1 = require("../../../services");
const models_1 = require("../models");
let IdentityServerController = class IdentityServerController {
    constructor(idpLoginService, user, jwtKeysRepository) {
        this.idpLoginService = idpLoginService;
        this.user = user;
        this.jwtKeysRepository = jwtKeysRepository;
    }
    async getConfig() {
        return this.idpLoginService.getOpenIdConfiguration();
    }
    async getToken(req) {
        return this.idpLoginService.generateToken(req);
    }
    async me() {
        if (!this.user) {
            throw new rest_1.HttpErrors.Unauthorized("Token Invalid" /* AuthErrorKeys.TokenInvalid */);
        }
        delete this.user.deviceInfo;
        return new models_1.AuthUser(this.user);
    }
    async logout(auth, req) {
        return this.idpLoginService.logoutUser(auth, req);
    }
    async generateKeys() {
        return this.idpLoginService.generateKeys();
    }
    async rotateKeys() {
        return this.idpLoginService.generateNewKey();
    }
    async getKeys() {
        return this.jwtKeysRepository.find({
            fields: { publicKey: true, id: true, keyId: true },
        });
    }
};
exports.IdentityServerController = IdentityServerController;
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.get)('/.well-known/openid-configuration', {
        security: core_2.OPERATION_SECURITY_SPEC,
        description: 'To get the openid configuration',
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'OpenId Configuration',
                content: {
                    [core_2.CONTENT_TYPE.JSON]: models_1.IdpConfiguration,
                },
            },
            ...core_2.ErrorCodes,
        },
    }),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", []),
    tslib_1.__metadata("design:returntype", Promise)
], IdentityServerController.prototype, "getConfig", null);
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.post)('/connect/token', {
        description: 'Send the code received from the POST /auth/login api and get refresh token and access token (webapps)',
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Token Response',
                content: {
                    [core_2.CONTENT_TYPE.JSON]: {
                        schema: { [core_2.X_TS_TYPE]: models_1.TokenResponse },
                    },
                },
            },
            ...core_2.ErrorCodes,
        },
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [models_1.AuthTokenRequest]),
    tslib_1.__metadata("design:returntype", Promise)
], IdentityServerController.prototype, "getToken", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, loopback4_authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.get)('/connect/userinfo', {
        security: core_2.OPERATION_SECURITY_SPEC,
        description: 'To get the user details',
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'User Object',
                content: {
                    [core_2.CONTENT_TYPE.JSON]: models_1.AuthUser,
                },
            },
            ...core_2.ErrorCodes,
        },
    }),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", []),
    tslib_1.__metadata("design:returntype", Promise)
], IdentityServerController.prototype, "me", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, loopback4_authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.post)('/connect/endsession', {
        security: core_2.OPERATION_SECURITY_SPEC,
        description: 'To logout',
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Success Response',
                content: {
                    [core_2.CONTENT_TYPE.JSON]: {
                        schema: { [core_2.X_TS_TYPE]: core_2.SuccessResponse },
                    },
                },
            },
            ...core_2.ErrorCodes,
        },
    }),
    tslib_1.__param(0, rest_1.param.header.string('Authorization', {
        description: 'This is the access token which is required to authenticate user.',
    })),
    tslib_1.__param(1, (0, rest_1.requestBody)({
        content: {
            [core_2.CONTENT_TYPE.JSON]: {
                schema: (0, rest_1.getModelSchemaRef)(models_1.AuthRefreshTokenRequest, {
                    partial: true,
                }),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, models_1.AuthRefreshTokenRequest]),
    tslib_1.__metadata("design:returntype", Promise)
], IdentityServerController.prototype, "logout", null);
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.post)('/connect/generate-keys', {
        description: 'Generate the set of public and private keys',
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'JWKS Keys',
            },
            ...core_2.ErrorCodes,
        },
    }),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", []),
    tslib_1.__metadata("design:returntype", Promise)
], IdentityServerController.prototype, "generateKeys", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */, {
        passReqToCallback: true,
    }),
    (0, loopback4_authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.post)('/connect/rotate-keys', {
        description: 'Generate the set of public and private keys',
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'JWKS Keys',
            },
            ...core_2.ErrorCodes,
        },
    }),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", []),
    tslib_1.__metadata("design:returntype", Promise)
], IdentityServerController.prototype, "rotateKeys", null);
tslib_1.__decorate([
    (0, loopback4_authorization_1.authorize)({ permissions: ['*'] }),
    (0, rest_1.get)('/connect/get-keys', {
        description: 'Get the public keys',
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'JWKS Keys',
            },
            ...core_2.ErrorCodes,
        },
    }),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", []),
    tslib_1.__metadata("design:returntype", Promise)
], IdentityServerController.prototype, "getKeys", null);
exports.IdentityServerController = IdentityServerController = tslib_1.__decorate([
    tslib_1.__param(0, (0, core_1.inject)('services.IdpLoginService')),
    tslib_1.__param(1, (0, core_1.inject)(loopback4_authentication_1.AuthenticationBindings.CURRENT_USER)),
    tslib_1.__param(2, (0, repository_1.repository)(repositories_1.JwtKeysRepository)),
    tslib_1.__metadata("design:paramtypes", [services_1.IdpLoginService, Object, repositories_1.JwtKeysRepository])
], IdentityServerController);
//# sourceMappingURL=identity-server.controller.js.map