"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SignupBearerVerifyProvider = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const context_1 = require("@loopback/context");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_1 = require("@sourceloop/core");
const jwt = tslib_1.__importStar(require("jsonwebtoken"));
const jose = tslib_1.__importStar(require("node-jose"));
const keys_1 = require("../keys");
const repositories_1 = require("../repositories");
let SignupBearerVerifyProvider = class SignupBearerVerifyProvider {
    constructor(jwtKeysRepo, logger, authConfig) {
        this.jwtKeysRepo = jwtKeysRepo;
        this.logger = logger;
        this.authConfig = authConfig;
    }
    value() {
        return async (token, req) => {
            var _a;
            let result;
            try {
                if ((_a = this.authConfig) === null || _a === void 0 ? void 0 : _a.useSymmetricEncryption) {
                    result = jwt.verify(token, process.env.JWT_SECRET, {
                        issuer: process.env.JWT_ISSUER,
                        algorithms: ['HS256'],
                    });
                }
                else {
                    // Get the key that matches the token's kid
                    const decoded = jwt.decode(token.trim(), { complete: true });
                    if (!decoded) {
                        throw new Error('Code is not valid');
                    }
                    const kid = decoded === null || decoded === void 0 ? void 0 : decoded.header.kid;
                    // Load the JWKS
                    const key = await this.jwtKeysRepo.findOne({
                        where: {
                            keyId: kid,
                        },
                    });
                    if (!key) {
                        throw new Error('Key not found for verification');
                    }
                    // Convert the JWK to PEM format for verification
                    const jwkKey = await jose.JWK.asKey(key.publicKey, 'pem');
                    const pem = jwkKey.toPEM(false);
                    result = jwt.verify(token, pem, {
                        issuer: process.env.JWT_ISSUER,
                        algorithms: ['RS256'],
                    });
                }
            }
            catch (error) {
                this.logger.error(JSON.stringify(error));
                throw new rest_1.HttpErrors.Unauthorized('TokenExpired');
            }
            return result;
        };
    }
};
exports.SignupBearerVerifyProvider = SignupBearerVerifyProvider;
exports.SignupBearerVerifyProvider = SignupBearerVerifyProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.JwtKeysRepository)),
    tslib_1.__param(1, (0, context_1.inject)(core_1.LOGGER.LOGGER_INJECT)),
    tslib_1.__param(2, (0, context_1.inject)(keys_1.AuthServiceBindings.Config, { optional: true })),
    tslib_1.__metadata("design:paramtypes", [repositories_1.JwtKeysRepository, Object, Object])
], SignupBearerVerifyProvider);
//# sourceMappingURL=bearer-verify.provider.js.map