"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JWTAsymmetricSignerProvider = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const jwt = tslib_1.__importStar(require("jsonwebtoken"));
const repositories_1 = require("../repositories");
let JWTAsymmetricSignerProvider = class JWTAsymmetricSignerProvider {
    constructor(jwtKeysRepo) {
        this.jwtKeysRepo = jwtKeysRepo;
    }
    value() {
        return async (data, options) => {
            // Load private keys
            const privateKeys = await this.jwtKeysRepo.find({
                order: ['createdOn DESC'],
            });
            if (!privateKeys.length) {
                throw new rest_1.HttpErrors.InternalServerError('No keys found');
            }
            // Use the latest private key (assuming it's the last one added)
            const privateKey = privateKeys[0];
            const accessToken = jwt.sign(data, {
                key: privateKey.privateKey,
                passphrase: process.env.JWT_PRIVATE_KEY_PASSPHRASE,
            }, {
                ...options,
                algorithm: 'RS256',
                issuer: process.env.JWT_ISSUER,
                keyid: privateKey.keyId,
            });
            return accessToken;
        };
    }
};
exports.JWTAsymmetricSignerProvider = JWTAsymmetricSignerProvider;
exports.JWTAsymmetricSignerProvider = JWTAsymmetricSignerProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.JwtKeysRepository)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.JwtKeysRepository])
], JWTAsymmetricSignerProvider);
//# sourceMappingURL=jwt-asymmetric-signer.provider.js.map