"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JWTAsymmetricVerifierProvider = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const jwt = tslib_1.__importStar(require("jsonwebtoken"));
const jose = tslib_1.__importStar(require("node-jose"));
const repositories_1 = require("../repositories");
let JWTAsymmetricVerifierProvider = class JWTAsymmetricVerifierProvider {
    constructor(jwtKeysRepo) {
        this.jwtKeysRepo = jwtKeysRepo;
    }
    value() {
        return async (token, options) => {
            // Get the key that matches the token's kid
            const decoded = jwt.decode(token.trim(), { complete: true });
            if (!decoded) {
                throw new Error('Token is not valid');
            }
            const kid = decoded === null || decoded === void 0 ? void 0 : decoded.header.kid;
            // Load the JWKS
            const key = await this.jwtKeysRepo.findOne({
                where: {
                    keyId: kid,
                },
            });
            if (!key) {
                throw new Error('Key not found for verification');
            }
            // Convert the JWK to PEM format for verification
            const jwkKey = await jose.JWK.asKey(key.publicKey, 'pem');
            const pem = jwkKey.toPEM(false);
            // Verify the token with the retrieved PEM-formatted public key
            const payload = jwt.verify(token, pem, {
                ...options,
                issuer: process.env.JWT_ISSUER,
                algorithms: ['RS256'],
            });
            return payload;
        };
    }
};
exports.JWTAsymmetricVerifierProvider = JWTAsymmetricVerifierProvider;
exports.JWTAsymmetricVerifierProvider = JWTAsymmetricVerifierProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.JwtKeysRepository)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.JwtKeysRepository])
], JWTAsymmetricVerifierProvider);
//# sourceMappingURL=jwt-asymmetric-verifier.provider.js.map