"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JWTSignerProvider = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const jwt = tslib_1.__importStar(require("jsonwebtoken"));
const keys_1 = require("../keys");
const repositories_1 = require("../repositories");
let JWTSignerProvider = class JWTSignerProvider {
    constructor(jwtKeysRepo, authConfig) {
        this.jwtKeysRepo = jwtKeysRepo;
        this.authConfig = authConfig;
    }
    value() {
        return async (data, options) => {
            var _a;
            let accessToken;
            if ((_a = this.authConfig) === null || _a === void 0 ? void 0 : _a.useSymmetricEncryption) {
                accessToken = jwt.sign(data, process.env.JWT_SECRET, {
                    ...options,
                    issuer: process.env.JWT_ISSUER,
                    algorithm: 'HS256',
                });
            }
            else {
                // Load private keys
                const privateKeys = await this.jwtKeysRepo.find({
                    order: ['createdOn DESC'],
                });
                if (!privateKeys.length) {
                    throw new rest_1.HttpErrors.InternalServerError('No keys found');
                }
                // Use the latest private key (assuming it's the last one added)
                const privateKey = privateKeys[0];
                accessToken = jwt.sign(data, {
                    key: privateKey.privateKey,
                    passphrase: process.env.JWT_PRIVATE_KEY_PASSPHRASE,
                }, {
                    ...options,
                    algorithm: 'RS256',
                    issuer: process.env.JWT_ISSUER,
                    keyid: privateKey.keyId,
                });
            }
            return accessToken;
        };
    }
};
exports.JWTSignerProvider = JWTSignerProvider;
exports.JWTSignerProvider = JWTSignerProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.JwtKeysRepository)),
    tslib_1.__param(1, (0, core_1.inject)(keys_1.AuthServiceBindings.Config, { optional: true })),
    tslib_1.__metadata("design:paramtypes", [repositories_1.JwtKeysRepository, Object])
], JWTSignerProvider);
//# sourceMappingURL=jwt-signer.provider.js.map