"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JWTAsymmetricVerifierProvider = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const jwt = tslib_1.__importStar(require("jsonwebtoken"));
const jose = tslib_1.__importStar(require("node-jose"));
const keys_1 = require("../keys");
const repositories_1 = require("../repositories");
let JWTAsymmetricVerifierProvider = class JWTAsymmetricVerifierProvider {
    constructor(jwtKeysRepo, authConfig) {
        this.jwtKeysRepo = jwtKeysRepo;
        this.authConfig = authConfig;
    }
    value() {
        return async (code, options) => {
            var _a;
            let payload;
            if ((_a = this.authConfig) === null || _a === void 0 ? void 0 : _a.useSymmetricEncryption) {
                payload = jwt.verify(code, process.env.JWT_SECRET, {
                    ...options,
                    issuer: process.env.JWT_ISSUER,
                    algorithms: ['HS256'],
                });
            }
            else {
                // Get the key that matches the token's kid
                const decoded = jwt.decode(code.trim(), { complete: true });
                if (!decoded) {
                    throw new Error('Code is not valid');
                }
                const kid = decoded === null || decoded === void 0 ? void 0 : decoded.header.kid;
                // Load the JWKS
                const key = await this.jwtKeysRepo.findOne({
                    where: {
                        keyId: kid,
                    },
                });
                if (!key) {
                    throw new Error('Key not found for verification');
                }
                // Convert the JWK to PEM format for verification
                const jwkKey = await jose.JWK.asKey(key.publicKey, 'pem');
                const pem = jwkKey.toPEM(false);
                // Verify the token with the retrieved PEM-formatted public key
                payload = jwt.verify(code, pem, {
                    ...options,
                    issuer: process.env.JWT_ISSUER,
                    algorithms: ['RS256'],
                });
            }
            return payload;
        };
    }
};
exports.JWTAsymmetricVerifierProvider = JWTAsymmetricVerifierProvider;
exports.JWTAsymmetricVerifierProvider = JWTAsymmetricVerifierProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.JwtKeysRepository)),
    tslib_1.__param(1, (0, core_1.inject)(keys_1.AuthServiceBindings.Config, { optional: true })),
    tslib_1.__metadata("design:paramtypes", [repositories_1.JwtKeysRepository, Object])
], JWTAsymmetricVerifierProvider);
//# sourceMappingURL=jwt-verify.provider.js.map